@@ -240,10 +240,11 @@ class KitsuConfig(flow.Object):
     project_id = flow.Computed(
         cached=True
     )
+    uploadable_files = flow.Param("")
+    bindings = flow.Child(KitsuBindings)
     gazu_api = flow.Child(KitsuAPIWrapper).ui(
         hidden=True
     )
-    bindings = flow.Child(KitsuBindings)
 
     def child_value_changed(self, child_value):
         self.project_id.touch()
@@ -394,6 +395,12 @@ class Project(flow.Object):
 
     def get_user(self):
         return self.user.current_user_id.get()
+    
+    def get_user_from_name(self, name):
+        if not self.admin.users.has_mapped_name(name):
+            return None
+        
+        return self.admin.users[name]
 
     def get_current_site(self):
         """
