@@ -22,6 +22,7 @@ from .maputils import SimpleCreateAction, ClearMapAction
 
 from .site import SyncMap, Request, RequestAs
 from .runners import LaunchSessionWorker, CHOICES, CHOICES_ICONS
+from .kitsu import KitsuTaskStatus
 
 from libreflow.utils.b3d import wrap_python_expr
 pyversion = sys.version_info
@@ -53,13 +54,13 @@ class RevisionsChoiceValue(flow.values.ChoiceValue):
     _file = flow.Parent(2)
 
     def choices(self):
-        return self._file.get_revisions().mapped_names()
+        return self._file.get_revision_names(sync_status='Available')
 
     def revert_to_default(self):
         if self._file.is_empty():
             self.set("")
 
-        revision = self._file.get_head_revision()
+        revision = self._file.get_head_revision(sync_status='Available')
         
         if revision is None:
             revision = self._file.get_working_copy()
@@ -350,7 +351,7 @@ class Revision(flow.Object):
         if from_current_user:
             return self.name() == self.root().project().get_user()
 
-        return self.name() == self.user.get()
+        return re.match(r'v\d\d\d', self.name()) is None
 
     def get_sync_status(self, site_name=None, exchange=False):
         """
@@ -1253,6 +1254,131 @@ class PublishAndRenderPlayblastAction(PublishFileAction):
         return self._file.render_playblast.run("Render")
 
 
+class FileRevisionNameChoiceValue(flow.values.ChoiceValue):
+
+    STRICT_CHOICES = False
+    action = flow.Parent()
+
+    def get_file(self):
+        return self.action._file
+
+    def choices(self):
+        return self.get_file().get_revision_names(
+            sync_status='Available',
+            published_only=True
+        )
+    
+    def revert_to_default(self):
+        source_file = self.get_file()
+        
+        if not source_file:
+            self.set(None)
+            return
+        
+        revision = source_file.get_head_revision(sync_status="Available")
+        self.set(revision.name() if revision else None)
+
+
+class UploadPlayblastToKitsu(flow.Action):
+    
+    ICON = ('icons.libreflow', 'kitsu')
+    
+    _file = flow.Parent()
+    
+    revision_name = flow.Param(None, FileRevisionNameChoiceValue)
+    kitsu_settings = flow.Label('<h3>Kitsu settings</h3>').ui(icon=('icons.libreflow', 'kitsu'))
+    current_task_status = flow.Computed()
+    target_task_type = flow.Computed()
+    target_task_status = flow.Param('Work In Progress', KitsuTaskStatus)
+    comment = flow.SessionParam().ui(editor='textarea')
+    
+    def __init__(self, parent, name):
+        super(UploadPlayblastToKitsu, self).__init__(parent, name)
+        kitsu_bindings = self.root().project().kitsu_bindings()
+        file_settings = get_contextual_dict(self._file, 'settings')
+        entity_data = kitsu_bindings.get_entity_data(file_settings)
+        self._kitsu_entity = kitsu_bindings.get_kitsu_entity(entity_data)
+    
+    def allow_context(self, context):
+        kitsu_config = self.root().project().admin.kitsu
+        patterns = kitsu_config.uploadable_files.get().split(',')
+
+        for pattern in patterns:
+            pattern = pattern.replace(' ', '')
+            if not fnmatch.fnmatch(self._file.display_name.get(), pattern):
+                return False
+        
+        return not self._file.is_empty(on_current_site=True)
+    
+    def get_buttons(self):
+        # Reset params to defaults
+        self.revision_name.revert_to_default()
+        self.target_task_status.revert_to_default()
+        
+        # Check if the file is linked to a Kitsu entity
+        task_type = self.target_task_type.get()
+        
+        if self._kitsu_entity is None or task_type is None:
+            self.message.set((
+                "<h2><font color=#D5000D>The Kitsu entity %s belongs to "
+                "couldn't be detected.</font></h2>Please contact the "
+                "support on the chat." % self._file.display_name.get()
+            ))
+            return ['Cancel']
+        
+        # Check if current user is assigned to a Kitsu task this file is made for
+        kitsu_api = self.root().project().kitsu_api()
+        user = kitsu_api.get_user()
+        task = kitsu_api.get_task(self._kitsu_entity, task_type)
+        
+        if user is None or task is None or not kitsu_api.user_is_assigned(user, task):
+            self.message.set((
+                "<h2><font color=#D5000D>You (%s) are not assigned to "
+                "the task this file has been created for.</font></h2>"
+                % self.root().project().get_user()
+            ))
+            return ['Cancel']
+        
+        self.message.set("<h2>Upload playblast to Kitsu</h2>")
+        
+        return ['Upload', 'Cancel']
+    
+    def compute_child_value(self, child_value):
+        if self._kitsu_entity is None:
+            child_value.set(None)
+            return
+        
+        kitsu_api = self.root().project().kitsu_api()
+        kitsu_bindings = self.root().project().kitsu_bindings()
+        
+        if child_value is self.target_task_type:
+            task_type = kitsu_bindings.get_task_type(
+                self._file.display_name.get()
+            )
+            self.target_task_type.set(task_type)
+        elif child_value is self.current_task_status:
+            task_status = kitsu_api.get_task_current_status(
+                self._kitsu_entity,
+                self.target_task_type.get()
+            )
+            self.current_task_status.set(task_status)
+    
+    def run(self, button):
+        if button == 'Cancel':
+            return
+        
+        file_path = self._file.get_revision(self.revision_name.get()).get_path()
+        kitsu_api = self.root().project().kitsu_api()
+        
+        kitsu_api.upload_preview(
+            kitsu_entity=self._kitsu_entity,
+            task_type_name=self.target_task_type.get(),
+            task_status_name=self.target_task_status.get(),
+            file_path=self._file.get_revision(self.revision_name.get()).get_path(),
+            comment=self.comment.get(),
+        )
+
+
 class RequestTrackedFileAction(flow.Action):
 
     _file = flow.Parent()
@@ -1310,6 +1436,9 @@ class TrackedFile(File):
     unlock_action = flow.Child(UnlockAction).ui(label="Unlock")
     search_existing_revisions = flow.Child(SearchExistingRevisions)
     request = flow.Child(RequestTrackedFileAction)
+    upload_playblast = flow.Child(UploadPlayblastToKitsu).ui(
+        label="Upload to Kitsu"
+    )
 
     with flow.group("Open with"):
         open_with_blender = flow.Child(OpenWithBlenderAction).ui(label="Blender")
@@ -1420,8 +1549,17 @@ class TrackedFile(File):
         
         return exists
 
-    def is_empty(self):
-        return not bool(len(self.get_revisions()))
+    def is_empty(self, on_current_site=True):
+        revisions = self.get_revisions()
+        
+        if not on_current_site:
+            return not bool(revisions.mapped_names())
+        
+        for r in revisions.mapped_items():
+            if r.get_sync_status() == 'Available':
+                return False
+        
+        return True
 
     def get_last_edit_time(self):
         seen_name = self.current_user_sees.get()
@@ -1715,42 +1853,6 @@ class TrackedFile(File):
             super(TrackedFile, self).compute_child_value(child_value)
 
 
-class FileRevisionNameChoiceValue(flow.values.ChoiceValue):
-
-    STRICT_CHOICES = False
-    action = flow.Parent()
-
-    def get_file(self):
-        return self.action._file
-
-    def choices(self):
-        source_file = self.get_file()
-        names = []
-        
-        if not source_file:
-            return names
-        
-        for rev in source_file.get_revisions().mapped_items():
-            if rev.get_sync_status() == "Available":
-                names.append(rev.name())
-        
-        return names
-    
-    def revert_to_default(self):
-        source_file = self.get_file()
-        
-        if not source_file:
-            self.set(None)
-            return
-        
-        revision = source_file.get_head_revision(sync_status="Available")
-
-        if not revision:
-            revision = source_file.get_working_copy()
-        
-        self.set(revision.name() if revision else None)
-
-
 class FileRefRevisionNameChoiceValue(FileRevisionNameChoiceValue):
 
     def get_file(self):
