@@ -1,4 +1,6 @@
 import gazu
+import os
+import fnmatch
 
 from kabaret import flow
 
@@ -122,12 +124,123 @@ class KitsuAPIWrapper(flow.Object):
             return None
 
         return gazu.asset.get_asset_type(asset["entity_type_id"])
+    
+    def get_task(self, entity, task_type_name):
+        task_type = gazu.task.get_task_type_by_name(task_type_name)
+        
+        # Check if task type is valid
+        if task_type is None:
+            task_types = gazu.task.all_task_statuses()
+            names = [tt['name'] for tt in task_types]
+            self.root().session().log_error((
+                f"Invalid task type '{task_type_name}'. "
+                "Should be one of " + str(names) + "."
+            ))
+            return None
+        
+        task = gazu.task.get_task_by_entity(entity, task_type)
+        
+        if task is None:
+            self.root().session().log_error("Invalid Kitsu entity")
+            return None
+        
+        task = gazu.task.get_task(task['id'])
+        
+        return task
+    
+    def get_task_current_status(self, entity, task_type_name):
+        task = self.get_task(entity, task_type_name)
+        
+        if task is None:
+            return None
+        
+        return task['task_status']['name']
+    
+    def get_user(self, project_user_name=None):
+        if project_user_name is None:
+            project_user_name = self.root().project().get_user()
+        
+        user = self.root().project().get_user_from_name(project_user_name)
+        
+        if user is None:
+            self.root().session().log_error((
+                f"No user '{project_user_name}' registered in this project"
+            ))
+            return False
+        
+        user_kitsu_id = user.kitsu_id.get()
+        kitsu_user = gazu.person.get_person_by_desktop_login(user_kitsu_id)
+        
+        if kitsu_user is None:
+            kitsu_user = gazu.person.get_person_by_email(user_kitsu_id)
+        
+        return kitsu_user
+    
+    def user_is_assigned(self, kitsu_user, kitsu_task):
+        kitsu_id = kitsu_user.get('id', None)
+        
+        if kitsu_id is None:
+            self.root().session().log_error("Invalid Kitsu user")
+            return None
+        
+        assignees = kitsu_task.get('assignees', None)
+        
+        if assignees is None:
+            self.root().session().log_error("Invalid Kitsu task")
+            return None
+        
+        return kitsu_id in assignees
+    
+    def upload_preview(self, kitsu_entity, task_type_name, task_status_name, file_path, comment="", user_name=None):
+        # Get user
+        user = self.get_user(user_name)
+        
+        # Get task
+        task = self.get_task(kitsu_entity, task_type_name)
+        
+        if task is None:
+            return False
+        
+        # Check if uploading user is assigned to the task
+        if not self.user_is_assigned(user, task):
+            self.root().session().log_error((
+                f"User '{user_name}' is not assigned to task '{task_type_name}' "
+                "of entity '%s'." % kitsu_entity['name']
+            ))
+            return False
+        
+        # Add comment with preview
+        
+        # Check if preview file exists
+        if not os.path.exists(file_path):
+            self.root().session().log_error(
+                f"Preview file '{file_path}' does not exists."
+            )
+            return False
+        
+        task_status = gazu.task.get_task_status_by_name(task_status_name)
+        
+        # Check if status is valid
+        if task_status is None:
+            task_statuses = gazu.task.all_task_statuses()
+            names = [ts['name'] for ts in task_statuses]
+            self.root().session().log_error((
+                f"Invalid task status '{task_status_name}'."
+                "Should be one of " + str(names) + "."
+            ))
+            return False
+        
+        comment = gazu.task.add_comment(task, task_status, comment=comment)
+        gazu.task.add_preview(task, comment, file_path)
+        
+        return True
 
 
 class KitsuBindings(flow.Object):
 
     asset_types = flow.HashParam()
     asset_families = flow.HashParam()
+    task_types_by_file_names = flow.DictParam({})
 
     def _kitsu_api(self):
         return self.root().project().kitsu_api()
@@ -180,6 +293,63 @@ class KitsuBindings(flow.Object):
             return kitsu_asset_family
 
         return self.asset_families.get_key(kitsu_asset_family)
+    
+    def get_task(self, entity_data, task_type_name):
+        entity = self.get_entity(entity_data)
+        
+        if entity is None:
+            self.root().session().log_error("Invalid Kitsu entity")
+            return None
+        
+        return self._kitsu_api().get_task(entity, task_type_name)
+    
+    def get_task_type(self, file_name):
+        for pattern, type_name in self.task_types_by_file_names.get().items():
+            if fnmatch.fnmatch(pattern, file_name):
+                return type_name
+        
+        return None
+    
+    def get_entity_data(self, contextual_settings):
+        kitsu_api = self.root().project().kitsu_api()
+        entities_data = {
+            'shot': ['shot', 'sequence'],
+            'asset': ['asset_name'],
+        }
+        
+        entity_data = {}
+        
+        for entity_type, entity_keys in entities_data.items():
+            for key in entity_keys:
+                entity_data[key] = contextual_settings.get(key, None)
+            
+            if all(v is not None for v in entity_data.values()):
+                entity_data.update(dict(entity_type=entity_type))
+                return entity_data
+            else:
+                entity_data = {}
+        
+        return None
+    
+    def get_kitsu_entity(self, entity_data):
+        entity_type = entity_data['entity_type']
+        
+        if entity_type == 'shot':
+            return self._kitsu_api().get_shot_data(entity_data['shot'], entity_data['sequence'])
+        elif entity_type == 'asset':
+            return self._kitsu_api().get_asset_data(entity_data['asset_name'])
+        else:
+            return None
+
+
+class KitsuTaskStatus(flow.values.ChoiceValue):
+    
+    STRICT_CHOICES = False
+    
+    def choices(self):
+        task_statuses = gazu.task.all_task_statuses()
+        return [ts['name'] for ts in task_statuses]
+
 
 class UpdateKitsuSettings(flow.Action):
 
