@@ -68,206 +68,9 @@ class UserProfile(flow.Object):
             # Return local user name otherwise
             child_value.set(getpass.getuser())
 
-
-
-
-###################################################
-# This part is still users, but from an admin POV #
-###################################################
-
-
-
-class GotoBookmarkAction(flow.Action):
-
-    _bookmark = flow.Parent()
-
-    def needs_dialog(self):
-        return False
-
-    def run(self, button):
-        # This is overkill, but needed to the dynamicMap can use the same actions
-        bookmarks = self.root().project().get_user_bookmarks()
-        return self.get_result(goto=bookmarks[self._bookmark.name()].goto_oid.get())
-
-
-class RemoveFromBookmark(flow.Action):
-
-    _bookmark = flow.Parent()
-    _bookmarks = flow.Parent(2)
-
-    def needs_dialog(self):
-        return False
-
-    def run(self, button):
-        # This is overkill, but needed to the dynamicMap can use the same actions
-        bookmarks = self.root().project().get_user_bookmarks()
-        bookmarks.remove_bookmark(self._bookmark.name())
-        self._bookmarks.touch()
-
-
-class Bookmark(flow.values.Value):
-    goto_oid = flow.Param()
-    remove = flow.Child(RemoveFromBookmark)
-    goto = flow.Child(GotoBookmarkAction)
-
-
-class ToggleBookmarkAction(flow.Action):
-
-    _obj = flow.Parent()
-
-    def needs_dialog(self):
-        return False
-
-    def allow_context(self, context):
-        return context and context.endswith(".details")
-
-    def get_bookmarks(self):
-        return self.root().project().get_user_bookmarks()
-
-    def is_bookmarked(self):
-        return self.get_bookmarks().has_bookmark(self._obj.oid())
-
-    def run(self, button):
-        bookmarks = self.get_bookmarks()
-
-        if self.is_bookmarked():
-            self.root().session().log_debug("Remove %s to bookmarks" % self._obj.oid())
-            bookmarks.remove_bookmark(self._obj.oid())
-        else:
-            self.root().session().log_debug("Add %s to bookmarks" % self._obj.oid())
-            bookmarks.add_bookmark(self._obj.oid())
-        # Ideally this touch is needed, but we can save some of them
-        # bookmarks.touch()
-        self.root().project().user.my_bookmarks.touch()
-        return self.get_result(refresh=True)
-
     def _fill_ui(self, ui):
-        ui["label"] = ""
-
-        if self.is_bookmarked():
-            ui["icon"] = ("icons.gui", "star")
-        else:
-            ui["icon"] = ("icons.gui", "star-1")
-
-
-class UserBookmarks(flow.Map):
-    '''
-    This is the actual map where we store
-    the user's bookmarks, based on its existance
-    in the Users maps
-    '''
-
-    @classmethod
-    def mapped_type(cls):
-        return Bookmark
-
-    def _fill_row_cells(self, row, item):
-        oid = item.goto_oid.get()
-        objects = (
-            self.root()
-            .session()
-            .cmds.Flow.split_oid(oid, up_to_oid=self.root().project().oid())
-        )
-        object_names = [obj[0].split(":")[-1] for obj in objects]
-
-        row["Bookmark"] = " > ".join(object_names)
-    
-    def columns(self):
-         return ["Bookmark"]
-    
-    def has_bookmark(self, oid):
-        if "/" in oid:
-            name = oid[1:].replace("/", "_")
-        else:
-            name = oid
-        return True if name in self.mapped_names() else False
-
-    def add_bookmark(self, oid):
-        name = oid[1:].replace("/", "_")
-        bookmark = self.add(name)
-        bookmark.goto_oid.set(oid)
-        self.touch()
-
-    def remove_bookmark(self, oid):
-        if "/" in oid:
-            name = oid[1:].replace("/", "_")
-        else:
-            name = oid
-        if self.has_bookmark(name):
-            self[name].goto_oid.revert_to_default()
-            self.remove(name)
-        self.touch()
-
-    def _fill_row_style(self, style, item, row):
-        style["activate_oid"] = item.goto.oid()
-
-
-
-
-
-
-class MyBookmarks(flow.DynamicMap):
-
-    def mapped_names(self, page_num=0, page_size=None):
-        return self.root().project().get_user_bookmarks().mapped_names()
-
-    @classmethod
-    def mapped_type(cls):
-        return flow.injection.injectable(Bookmark)
-
-    def columns(self):
-        return ["Bookmark"]
-
-    def _fill_row_cells(self, row, item):
-        name = item.name()
-        bookmarks = self.root().project().get_user_bookmarks()
-        oid = bookmarks[name].goto_oid.get()
-        objects = (
-            self.root()
-            .session()
-            .cmds.Flow.split_oid(oid, up_to_oid=self.root().project().oid())
-        )
-        object_names = [obj[0].split(":")[-1] for obj in objects]
-
-        row["Bookmark"] = " > ".join(object_names)
-
-    def _fill_row_style(self, style, item, row):
-        name = item.name()
-        bookmarks = self.root().project().get_user_bookmarks()
-        oid = bookmarks[name].goto.oid()
-        style["activate_oid"] = oid
-
-
-    
-
-class UserProfile(flow.Object):
-    '''
-    This part is made for the usrer
-    '''
-    current_user_id = flow.Computed(cached=True)
-    my_bookmarks = flow.Child(MyBookmarks).ui(expanded=True)
-
-
-    def compute_child_value(self, child_value):
-        if child_value is self.current_user_id:
-            # Check env
-            if "USER_NAME" in os.environ:
-                child_value.set(os.environ["USER_NAME"])
-                return
-            
-            # Check user file
-            current_user_file = os.path.join(
-                self.root().project().project_settings_folder(),
-                "current_user.json"
-            )
-            if os.path.exists(current_user_file):
-                with open(current_user_file, "r") as f:
-                    user_config = json.load(f)
-                    child_value.set(user_config["username"])
-                    return
-
-            # Return local user name otherwise
-            child_value.set(getpass.getuser())
+        if self.root().project().show_login_page():
+            ui["custom_page"] = "libreflow.baseflow.LoginPageWidget"
 
 
 
